Linux SCSI subsystem development
 help / color / mirror / Atom feed
From: Don Brace <don.brace@pmcs.com>
To: scott.teel@pmcs.com, Kevin.Barnett@pmcs.com,
	scott.benesh@pmcs.com, james.bottomley@parallels.com,
	hch@infradead.org, Justin.Lindley@pmcs.com, elliott@hpe.com
Cc: linux-scsi@vger.kernel.org
Subject: [PATCH v2 15/27] hpsa: simplify update scsi devices
Date: Wed, 04 Nov 2015 15:51:27 -0600	[thread overview]
Message-ID: <20151104215127.15472.61739.stgit@brunhilda> (raw)
In-Reply-To: <20151104214910.15472.23179.stgit@brunhilda>

From: Kevin Barnett <kevin.barnett@pmcs.com>

remove repeated calculation that checks for physical
or logical devices.

Reviewed-by: Scott Teel <scott.teel@pmcs.com>
Reviewed-by: Justin Lindley <justin.lindley@pmcs.com>
Reviewed-by: Kevin Barnett <kevin.barnett@pmcs.com>
Reviewed-by: Tomas Henzl <thenzl@redhat.com>
Reviewed-by: Matthew R. Ochs <mrochs@linux.vnet.ibm.com>
Reviewed-by: Hannes Reinecke <hare@suse.de>
Signed-off-by: Don Brace <don.brace@pmcs.com>
---
 drivers/scsi/hpsa.c |   22 +++++++++++++---------
 drivers/scsi/hpsa.h |    1 +
 2 files changed, 14 insertions(+), 9 deletions(-)

diff --git a/drivers/scsi/hpsa.h b/drivers/scsi/hpsa.h
index a6ead07..50e4780 100644
--- a/drivers/scsi/hpsa.h
+++ b/drivers/scsi/hpsa.h
@@ -37,6 +37,7 @@ struct hpsa_scsi_dev_t {
 	unsigned int devtype;
 	int bus, target, lun;		/* as presented to the OS */
 	unsigned char scsi3addr[8];	/* as presented to the HW */
+	u8 physical_device : 1;
 	u8 expose_device;
 #define RAID_CTLR_LUNID "\0\0\0\0\0\0\0\0"
 	unsigned char device_id[16];    /* from inquiry pg. 0x83 */


  parent reply	other threads:[~2015-11-04 21:55 UTC|newest]

Thread overview: 41+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2015-11-04 21:49 [PATCH v2 00/27] hpsa updates Don Brace
2015-11-04 21:50 ` [PATCH v2 01/27] hpsa: remove unused parameter hostno Don Brace
2015-11-06 14:22   ` Tomas Henzl
2015-11-04 21:50 ` [PATCH v2 02/27] hpsa: stop zeroing reset_cmds_out and ioaccel_cmds_out during rescan Don Brace
2015-11-04 21:50 ` [PATCH v2 03/27] hpsa: remove unused hpsa_tag_discard_error_bits Don Brace
2015-11-05 15:30   ` Manoj Kumar
2015-11-04 21:50 ` [PATCH v2 04/27] hpsa: change devtype to unsigned Don Brace
2015-11-04 21:50 ` [PATCH v2 05/27] hpsa: check for null arguments to dev_printk Don Brace
2015-11-09  9:37   ` Hannes Reinecke
2015-11-04 21:50 ` [PATCH v2 06/27] hpsa: fix null device issues Don Brace
2015-11-09  9:38   ` Hannes Reinecke
2015-11-04 21:50 ` [PATCH v2 07/27] hpsa: allow driver requested rescans Don Brace
2015-11-04 21:50 ` [PATCH v2 08/27] hpsa: abandon rescans on memory alloaction failures Don Brace
2015-11-09  9:38   ` Hannes Reinecke
2015-11-04 21:50 ` [PATCH v2 09/27] hpsa: correct transfer length for 6 byte read/write commands Don Brace
2015-11-04 21:50 ` [PATCH v2 10/27] hpsa: fix hpsa_adjust_hpsa_scsi_table Don Brace
2015-11-09  9:39   ` Hannes Reinecke
2015-11-04 21:51 ` [PATCH v2 11/27] hpsa: fix physical target reset Don Brace
2015-11-04 21:51 ` [PATCH v2 12/27] hpsa: correct check for non-disk devices Don Brace
2015-11-04 21:51 ` [PATCH v2 13/27] hpsa: correct ioaccel2 sg chain len Don Brace
2015-11-04 21:51 ` [PATCH v2 14/27] hpsa: simplify check for device exposure Don Brace
2015-11-04 21:51 ` Don Brace [this message]
2015-11-04 21:51 ` [PATCH v2 16/27] hpsa: add function is_logical_device Don Brace
2015-11-04 21:51 ` [PATCH v2 17/27] hpsa: enhance hpsa_get_device_id Don Brace
2015-11-09  9:40   ` Hannes Reinecke
2015-11-04 21:51 ` [PATCH v2 18/27] hpsa: refactor hpsa_figure_bus_target_lun Don Brace
2015-11-05 16:18   ` Matthew R. Ochs
2015-11-04 21:51 ` [PATCH v2 19/27] hpsa: move scsi_add_device and scsi_remove_device calls to new function Don Brace
2015-11-04 21:51 ` [PATCH v2 20/27] hpsa: generalize external arrays Don Brace
2015-11-05 16:23   ` Matthew R. Ochs
2015-11-05 19:51     ` Don Brace
2015-11-04 21:52 ` [PATCH v2 21/27] hpsa: eliminate fake lun0 enclosures Don Brace
2015-11-04 21:52 ` [PATCH v2 22/27] hpsa: add discovery polling for PT RAID devices Don Brace
2015-11-04 21:52 ` [PATCH v2 23/27] hpsa: disable report lun data caching Don Brace
2015-11-04 21:52 ` [PATCH v2 24/27] hpsa: enhance device messages Don Brace
2015-11-04 21:52 ` [PATCH v2 25/27] hpsa: fix multiple issues in path_info_show Don Brace
2015-11-04 21:52 ` [PATCH v2 26/27] hpsa: add in sas transport class Don Brace
2015-11-04 21:52 ` [PATCH v2 27/27] hpsa: bump the driver version Don Brace
2015-11-06 14:30 ` [PATCH v2 00/27] hpsa updates Tomas Henzl
2015-11-06 15:05   ` Don Brace
2015-11-09 17:46 ` Martin K. Petersen

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20151104215127.15472.61739.stgit@brunhilda \
    --to=don.brace@pmcs.com \
    --cc=Justin.Lindley@pmcs.com \
    --cc=Kevin.Barnett@pmcs.com \
    --cc=elliott@hpe.com \
    --cc=hch@infradead.org \
    --cc=james.bottomley@parallels.com \
    --cc=linux-scsi@vger.kernel.org \
    --cc=scott.benesh@pmcs.com \
    --cc=scott.teel@pmcs.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
diff --git a/drivers/scsi/hpsa.c b/drivers/scsi/hpsa.c
index 77c14ae..62df480 100644
--- a/drivers/scsi/hpsa.c
+++ b/drivers/scsi/hpsa.c
@@ -3752,6 +3752,7 @@ static void hpsa_update_scsi_devices(struct ctlr_info *h)
 	int ncurrent = 0;
 	int i, n_ext_target_devs, ndevs_to_allocate;
 	int raid_ctlr_position;
+	bool physical_device;
 	DECLARE_BITMAP(lunzerobits, MAX_EXT_TARGETS);
 
 	currentsd = kzalloc(sizeof(*currentsd) * HPSA_MAX_DEVICES, GFP_KERNEL);
@@ -3812,16 +3813,16 @@ static void hpsa_update_scsi_devices(struct ctlr_info *h)
 		int rc = 0;
 		int phys_dev_index = i - (raid_ctlr_position == 0);
 
+		physical_device = i < nphysicals + (raid_ctlr_position == 0);
+
 		/* Figure out where the LUN ID info is coming from */
 		lunaddrbytes = figure_lunaddrbytes(h, raid_ctlr_position,
 			i, nphysicals, nlogicals, physdev_list, logdev_list);
 
 		/* skip masked non-disk devices */
-		if (MASKED_DEVICE(lunaddrbytes))
-			if (i < nphysicals + (raid_ctlr_position == 0) &&
-				(physdev_list->
-				LUN[phys_dev_index].device_flags & 0x01))
-				continue;
+		if (MASKED_DEVICE(lunaddrbytes) && physical_device &&
+			(physdev_list->LUN[phys_dev_index].device_flags & 0x01))
+			continue;
 
 		/* Get device type, vendor, model, device id */
 		rc = hpsa_update_device_info(h, lunaddrbytes, tmpdevice,
@@ -3857,10 +3858,13 @@ static void hpsa_update_scsi_devices(struct ctlr_info *h)
 		}
 
 		*this_device = *tmpdevice;
+		this_device->physical_device = physical_device;
 
-		/* do not expose masked devices */
-		if (MASKED_DEVICE(lunaddrbytes) &&
-			i < nphysicals + (raid_ctlr_position == 0))
+		/*
+		 * Expose all devices except for physical devices that
+		 * are masked.
+		 */
+		if (MASKED_DEVICE(lunaddrbytes) && this_device->physical_device)
 			this_device->expose_device = 0;
 		else
 			this_device->expose_device = 1;
@@ -3878,7 +3882,7 @@ static void hpsa_update_scsi_devices(struct ctlr_info *h)
 				ncurrent++;
 			break;
 		case TYPE_DISK:
-			if (i < nphysicals + (raid_ctlr_position == 0)) {
+			if (this_device->physical_device) {
 				/* The disk is in HBA mode. */
 				/* Never use RAID mapper in HBA mode. */
 				this_device->offload_enabled = 0;